<template>
  <BasicModal width="800px" :height=600 v-bind="$attrs" @register="register" :title="t('储位盘点明细列表')" @ok="handleSubmit">
    <div class="pt-3px pr-3px">
      <BasicForm @register="registerForm" :model="model" />
    </div>
    <div>
      <a-button type="primary" class="mr-4" @click="handleSelect"> {{t('搜索')}} </a-button>
      <BasicTable @register="registerTable" :dataSource="Ldtl_Data" ref="tableRef" 
      :canResize="canResize" :loading="loading" :striped="striped" :bordered="border" :pagination="pagination"
          showTableSetting>
        <!-- <template #toolbar>
                <a-button type="primary" @click="handleCreate"> 新增盘点 </a-button>
              </template> -->
      </BasicTable>
      
    </div>
  </BasicModal>
</template>
<script lang="ts">
import { defineComponent, ref, unref } from 'vue';
import { BasicModal, useModalInner } from '/@/components/Modal';
import { BasicForm, FormSchema, useForm } from '/@/components/Form/index';
//import { getTreeList } from '/@/api/tigerapi/dept';
import { BasicTable, TableAction, TableActionType, useTable } from '/@/components/Table';
import { LdtlColumns } from './inventory.data';
import { getLdtlListByPage,optionsListApiLdtlStatus,optionsListApiLdtlResult } from '/@/api/tigerapi/wms/inventory';
import { iWMS_COUNT_MDTL } from '/@/api/tigerapi/model/warehoueseModel';
import { useI18n } from '/@/hooks/web/useI18n';
import{ useLocale } from '/@/locales/useLocale';
const { getLocale }=useLocale();
const { t } = useI18n('WMS.Count');
const schemas: FormSchema[] = [
{
  field: 'ITEM_CODE',
  component: 'Input',
  label: t('物料编码'),
  colProps: {
    span: 12,
  },
},
{
  field: 'COUNT_NO',
  component: 'Input',
  label: t('单据编码'),
  colProps: {
    span: 12,
  },
  show:false,
},
  {
    field: 'STATUS',
    label: t('状态'),
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: optionsListApiLdtlStatus,
      resultField: 'Data',
      labelField: unref(getLocale)=='zh_CN'?'Desc':'Name',
      valueField: 'Value',
      // onChange: (e, v) => {
      //   alert(e)
      //   console.log('ApiSelect====>:', e, v);
      // },
    },
  },
  {
    field: 'RESULT',
    label: t('结果'),
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: optionsListApiLdtlResult,
      resultField: 'Data',
      labelField: unref(getLocale)=='zh_CN'?'Desc':'Name',
      valueField: 'Value',
      // onChange: (e, v) => {
      //   alert(e)
      //   console.log('ApiSelect====>:', e, v);
      // },
    },
  }
];
export default defineComponent({
components: { BasicModal, BasicForm, BasicTable, TableAction },
props: {
  userData: { type: Object },
},
emit: ['success', 'register'],
setup(_, { emit }) {
  const modelRef = ref({});
  const tableRef = ref<Nullable<TableActionType>>(null);
  const canResize = ref(false);
  const loading = ref(true);
  const striped = ref(true);
  const border = ref(true);
  const pagination = ref<any>(false);
  const [
    registerForm,
    {
      setFieldsValue,
      validateFields
      // setProps
      //updateSchema,
      //validate
    },
  ] = useForm({
    labelWidth: 120,
    schemas,
    showActionButtonGroup: false,
    actionColOptions: {
      span: 24,
    },
  });
  const checkedKeys = ref<Array<string | number>>([]);
  const [registerTable, { reload }] = useTable({
    title: t('物料列表'),
    //api: getMdtlListByPage,
    columns: LdtlColumns,
    // formConfig: {
    //   labelWidth: 120,
    //   schemas: schemas,
    // },
    
    // useSearchForm: true,
    showTableSetting: true,
    rowKey: 'ITEM_CODE',
    rowSelection: {
      selectedRowKeys: checkedKeys,
      
      type: 'checkbox',
      // getCheckboxProps(record: Recordable) {
      //   // Demo: 第一行（id为0）的选择框禁用
      //   if (record.id === '0') {
      //     return { disabled: true };
      //   } else {
      //     return { disabled: false };
      //   }
      // },
      onSelect: onSelect,
      onSelectAll: onSelectAll,
    },
    //bordered: true,
    showIndexColumn: false,
    // actionColumn: {
    //   width: 80,
    //   title: '操作',
    //   dataIndex: 'action',
    //   slots: { customRender: 'action' },
    //   fixed: 'right' //undefined,
    // },
  });
  const [register, { setModalProps, closeModal }] = useModalInner((data) => {
    setModalProps({ confirmLoading: false });
    data && onDataReceive(data);
  });
  var Ldtl_Data=ref([] as iWMS_COUNT_MDTL[])
  async function onDataReceive(data) {
    pagination.value = { pageSize: 6 };
    console.log('Data Received', data);
    //方式1;
    setFieldsValue({
      COUNT_NO: data.data.COUNT_NO,
    });
    Ldtl_Data.value = await getLdtlListByPage(data.data.COUNT_NO)
    if(Ldtl_Data.value!=null){
      loading.value=false
    }
    // // 方式2
    //modelRef.value = { field2: data.data, field1: data.info };
    // const treeData = await getTreeList();
    // updateSchema([
    //   {
    //     field: 'USER_PWD',
    //     show: !unref(false),
    //   },
    //   {
    //     field: 'ORG_CODE',
    //     componentProps: { treeData },
    //   },
    // ]);
    // setProps({
    //   model:{ field2: data.data, field1: data.info }
    // })
  }

  // function handleVisibleChange(v) {
  //   v && props.userData && nextTick(() => onDataReceive(props.userData));
  // }

  async function handleSubmit() {
    try {

      // var values = '';
      // values=checkedKeys.value.join(',')
      closeModal();
      emit('success', {
        isUpdate: unref(false),
        //values: { values, id: 0 },
      });

    } finally {
      setModalProps({ confirmLoading: false });
    }
  }
  function onSelect(record, selected) {
      if (selected) {
        checkedKeys.value = [...checkedKeys.value, record.ITEM_CODE];
      } else {
        checkedKeys.value = checkedKeys.value.filter((ITEM_CODE) => ITEM_CODE !== record.ITEM_CODE);
      }
    }
    function onSelectAll(selected, selectedRows, changeRows) {
      const changeIds = changeRows.map((item) => item.ITEM_CODE);
      if (selected) {
        checkedKeys.value = [...checkedKeys.value, ...changeIds];
      } else {
        checkedKeys.value = checkedKeys.value.filter((ITEM_CODE) => {
          return !changeIds.includes(ITEM_CODE);
        });
      }
    }
    async function handleSelect(){
      var data = await validateFields();
      Ldtl_Data.value = await getLdtlListByPage(data)
    }

  return { 
    register, 
    schemas, 
    registerForm, 
    model: modelRef, 
    handleSubmit, 
    registerTable,
    onSelect,
    onSelectAll,
    setFieldsValue,
    handleSelect,
    validateFields,
    Ldtl_Data,
    tableRef,
    pagination,
    canResize,
    loading,
    striped,
    border,
    t
  };
},
});
</script>
